@@ -70,7 +70,7 @@ if (hasRequest('filter')) {
 	$header['right']->addVar('filter', $data['filter']);
 }
 if (hasRequest('mark_color')) {
-	$header['right']->addVar('mark_color', getRequest('mark_color'));
+	$header['right']->addVar('mark_color', $data['mark_color']);
 }
 
 $actions = [
@@ -159,7 +159,7 @@ if ($data['action'] == HISTORY_LATEST || $data['action'] == HISTORY_VALUES) {
 					]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 				)
 				->addRow(_('Value'),
-					(new CTextBox('filter', getRequest('filter', '')))
+					(new CTextBox('filter', $data['filter']))
 						->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
 						->removeId()
 				);
@@ -202,6 +202,9 @@ if ($data['itemids']) {
 		'pageFile' => (new CUrl('history.php'))
 			->setArgument('action', $data['action'])
 			->setArgument('itemids', $data['itemids'])
+			->setArgument('filter', $data['filter'])
+			->setArgument('filter_task', $data['filter_task'])
+			->setArgument('mark_color', $data['mark_color'])
 			->getUrl(),
 		'profileIdx' => $data['profileIdx'],
 		'profileIdx2' => $data['profileIdx2'],
@@ -210,7 +213,7 @@ if ($data['itemids']) {
 		'page' => $data['page'],
 		'filter' => $data['filter'],
 		'filter_task' => $data['filter_task'],
-		'mark_color' => getRequest('mark_color'),
+		'mark_color' => $data['mark_color'],
 		'plaintext' => $data['plaintext'],
 		'graphtype' => $data['graphtype']
 	]);
